# coding: utf-8

# flake8: noqa
"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

if __import__("typing").TYPE_CHECKING:
    # import models into model package
    from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest
    from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier
    from biotmed_settings_sdk.models.backup_request import BackupRequest
    from biotmed_settings_sdk.models.backup_response import BackupResponse
    from biotmed_settings_sdk.models.base_locale import BaseLocale
    from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue
    from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData
    from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData
    from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute
    from biotmed_settings_sdk.models.category import Category
    from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse
    from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute
    from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest
    from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute
    from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest
    from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute
    from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest
    from biotmed_settings_sdk.models.credentials import Credentials
    from biotmed_settings_sdk.models.custom_attribute import CustomAttribute
    from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse
    from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction
    from biotmed_settings_sdk.models.entity_type import EntityType
    from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction
    from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute
    from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute
    from biotmed_settings_sdk.models.error_response import ErrorResponse
    from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse
    from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse
    from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse
    from biotmed_settings_sdk.models.filter_v2 import FilterV2
    from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse
    from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse
    from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions
    from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse
    from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse
    from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse
    from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto
    from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation
    from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum
    from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto
    from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString
    from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale
    from biotmed_settings_sdk.models.link_configuration import LinkConfiguration
    from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage
    from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview
    from biotmed_settings_sdk.models.locales_response import LocalesResponse
    from biotmed_settings_sdk.models.metadata import Metadata
    from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto
    from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData
    from biotmed_settings_sdk.models.order import Order
    from biotmed_settings_sdk.models.organization_selection import OrganizationSelection
    from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration
    from biotmed_settings_sdk.models.page_metadata import PageMetadata
    from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse
    from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig
    from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest
    from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto
    from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig
    from biotmed_settings_sdk.models.plugin_response import PluginResponse
    from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator
    from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration
    from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest
    from biotmed_settings_sdk.models.restore_response import RestoreResponse
    from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2
    from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse
    from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse
    from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType
    from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse
    from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse
    from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview
    from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse
    from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse
    from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse
    from biotmed_settings_sdk.models.selectable_value import SelectableValue
    from biotmed_settings_sdk.models.selected_organization import SelectedOrganization
    from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest
    from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest
    from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto
    from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse
    from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration
    from biotmed_settings_sdk.models.template_attribute import TemplateAttribute
    from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse
    from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse
    from biotmed_settings_sdk.models.template_statistics import TemplateStatistics
    from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute
    from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute
    from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest
    from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute
    from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest
    from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse
    from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject
    from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject
    from biotmed_settings_sdk.models.version_response import VersionResponse
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import models into model package
from biotmed_settings_sdk.models.add_locale_request import AddLocaleRequest
from biotmed_settings_sdk.models.attribute_analytics_db_configuration import AttributeAnalyticsDbConfiguration
from biotmed_settings_sdk.models.attribute_identifier import AttributeIdentifier
from biotmed_settings_sdk.models.backup_request import BackupRequest
from biotmed_settings_sdk.models.backup_response import BackupResponse
from biotmed_settings_sdk.models.base_locale import BaseLocale
from biotmed_settings_sdk.models.base_selectable_value import BaseSelectableValue
from biotmed_settings_sdk.models.basic_attribute_data import BasicAttributeData
from biotmed_settings_sdk.models.basic_template_data import BasicTemplateData
from biotmed_settings_sdk.models.built_in_attribute import BuiltInAttribute
from biotmed_settings_sdk.models.category import Category
from biotmed_settings_sdk.models.code_snippet_response import CodeSnippetResponse
from biotmed_settings_sdk.models.create_built_in_attribute import CreateBuiltInAttribute
from biotmed_settings_sdk.models.create_code_snippet_request import CreateCodeSnippetRequest
from biotmed_settings_sdk.models.create_custom_attribute import CreateCustomAttribute
from biotmed_settings_sdk.models.create_plugin_request import CreatePluginRequest
from biotmed_settings_sdk.models.create_template_attribute import CreateTemplateAttribute
from biotmed_settings_sdk.models.create_template_request import CreateTemplateRequest
from biotmed_settings_sdk.models.credentials import Credentials
from biotmed_settings_sdk.models.custom_attribute import CustomAttribute
from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse
from biotmed_settings_sdk.models.entity_notifiable_action import EntityNotifiableAction
from biotmed_settings_sdk.models.entity_type import EntityType
from biotmed_settings_sdk.models.entity_type_built_in_action import EntityTypeBuiltInAction
from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute
from biotmed_settings_sdk.models.entity_type_template_attribute import EntityTypeTemplateAttribute
from biotmed_settings_sdk.models.error_response import ErrorResponse
from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse
from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse
from biotmed_settings_sdk.models.file_configuration_metadata_response import FileConfigurationMetadataResponse
from biotmed_settings_sdk.models.filter_v2 import FilterV2
from biotmed_settings_sdk.models.get_category_response import GetCategoryResponse
from biotmed_settings_sdk.models.get_entity_types_response import GetEntityTypesResponse
from biotmed_settings_sdk.models.get_notifiable_actions import GetNotifiableActions
from biotmed_settings_sdk.models.get_template_response import GetTemplateResponse
from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse
from biotmed_settings_sdk.models.interception_configuration_response import InterceptionConfigurationResponse
from biotmed_settings_sdk.models.interception_subscription_dto import InterceptionSubscriptionDto
from biotmed_settings_sdk.models.invalid_translation import InvalidTranslation
from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum
from biotmed_settings_sdk.models.json_nullable_list_interception_subscription_dto import JsonNullableListInterceptionSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_notification_subscription_dto import JsonNullableListNotificationSubscriptionDto
from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString
from biotmed_settings_sdk.models.json_nullable_set_base_locale import JsonNullableSetBaseLocale
from biotmed_settings_sdk.models.link_configuration import LinkConfiguration
from biotmed_settings_sdk.models.locale_translations_coverage import LocaleTranslationsCoverage
from biotmed_settings_sdk.models.locale_translations_overview import LocaleTranslationsOverview
from biotmed_settings_sdk.models.locales_response import LocalesResponse
from biotmed_settings_sdk.models.metadata import Metadata
from biotmed_settings_sdk.models.notification_subscription_dto import NotificationSubscriptionDto
from biotmed_settings_sdk.models.numeric_meta_data import NumericMetaData
from biotmed_settings_sdk.models.order import Order
from biotmed_settings_sdk.models.organization_selection import OrganizationSelection
from biotmed_settings_sdk.models.organization_selection_configuration import OrganizationSelectionConfiguration
from biotmed_settings_sdk.models.page_metadata import PageMetadata
from biotmed_settings_sdk.models.parent_template_response import ParentTemplateResponse
from biotmed_settings_sdk.models.partial_plugin_cors_config import PartialPluginCorsConfig
from biotmed_settings_sdk.models.partial_update_plugin_request import PartialUpdatePluginRequest
from biotmed_settings_sdk.models.partial_update_subscription_dto import PartialUpdateSubscriptionDto
from biotmed_settings_sdk.models.plugin_cors_config import PluginCorsConfig
from biotmed_settings_sdk.models.plugin_response import PluginResponse
from biotmed_settings_sdk.models.primary_administrator import PrimaryAdministrator
from biotmed_settings_sdk.models.reference_configuration import ReferenceConfiguration
from biotmed_settings_sdk.models.reset_system_request import ResetSystemRequest
from biotmed_settings_sdk.models.restore_response import RestoreResponse
from biotmed_settings_sdk.models.search_request_v2 import SearchRequestV2
from biotmed_settings_sdk.models.search_response_backup_response import SearchResponseBackupResponse
from biotmed_settings_sdk.models.search_response_code_snippet_response import SearchResponseCodeSnippetResponse
from biotmed_settings_sdk.models.search_response_entity_type import SearchResponseEntityType
from biotmed_settings_sdk.models.search_response_get_template_response import SearchResponseGetTemplateResponse
from biotmed_settings_sdk.models.search_response_interception_configuration_response import SearchResponseInterceptionConfigurationResponse
from biotmed_settings_sdk.models.search_response_locale_translations_overview import SearchResponseLocaleTranslationsOverview
from biotmed_settings_sdk.models.search_response_plugin_response import SearchResponsePluginResponse
from biotmed_settings_sdk.models.search_response_restore_response import SearchResponseRestoreResponse
from biotmed_settings_sdk.models.search_response_template_minimized_response import SearchResponseTemplateMinimizedResponse
from biotmed_settings_sdk.models.selectable_value import SelectableValue
from biotmed_settings_sdk.models.selected_organization import SelectedOrganization
from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest
from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest
from biotmed_settings_sdk.models.subscription_dto import SubscriptionDto
from biotmed_settings_sdk.models.system_properties_response import SystemPropertiesResponse
from biotmed_settings_sdk.models.template_analytics_db_configuration import TemplateAnalyticsDbConfiguration
from biotmed_settings_sdk.models.template_attribute import TemplateAttribute
from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse
from biotmed_settings_sdk.models.template_overview_response import TemplateOverviewResponse
from biotmed_settings_sdk.models.template_statistics import TemplateStatistics
from biotmed_settings_sdk.models.update_built_in_attribute import UpdateBuiltInAttribute
from biotmed_settings_sdk.models.update_custom_attribute import UpdateCustomAttribute
from biotmed_settings_sdk.models.update_locale_translations_response import UpdateLocaleTranslationsResponse
from biotmed_settings_sdk.models.update_locales_request import UpdateLocalesRequest
from biotmed_settings_sdk.models.update_template_attribute import UpdateTemplateAttribute
from biotmed_settings_sdk.models.update_template_request import UpdateTemplateRequest
from biotmed_settings_sdk.models.validate_locale_translations_response import ValidateLocaleTranslationsResponse
from biotmed_settings_sdk.models.validation_definition_metadata_object import ValidationDefinitionMetadataObject
from biotmed_settings_sdk.models.validation_definition_object import ValidationDefinitionObject
from biotmed_settings_sdk.models.version_response import VersionResponse

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from biotmed_settings_sdk.models.export_execution_response import ExportExecutionResponse
from biotmed_settings_sdk.models.exports_metadata_response import ExportsMetadataResponse
from biotmed_settings_sdk.models.import_execution_response import ImportExecutionResponse
from biotmed_settings_sdk.models.start_export_configuration_request import StartExportConfigurationRequest
from biotmed_settings_sdk.models.start_import_configuration_request import StartImportConfigurationRequest

from biotmed_settings_sdk.api_client import ApiClient, RequestSerialized
from biotmed_settings_sdk.api_response import ApiResponse
from biotmed_settings_sdk.rest import RESTResponseType


class ExportImportConfigurationAPIApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_exports_metadata(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ExportsMetadataResponse:
        """Get exported files metadata

        Get exported files metadata      This API requires **SETTINGS_CONFIGURATION_GET_EXPORTED_FILES_METADATA** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_exports_metadata_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ExportsMetadataResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_exports_metadata_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ExportsMetadataResponse]:
        """Get exported files metadata

        Get exported files metadata      This API requires **SETTINGS_CONFIGURATION_GET_EXPORTED_FILES_METADATA** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_exports_metadata_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ExportsMetadataResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_exports_metadata_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get exported files metadata

        Get exported files metadata      This API requires **SETTINGS_CONFIGURATION_GET_EXPORTED_FILES_METADATA** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_exports_metadata_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ExportsMetadataResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_exports_metadata_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/configuration/exports/metadata',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_last_export_execution(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ExportExecutionResponse:
        """Get the last export execution

        Get the last export execution    In case there was never been an export execution, an 404 error will be returned with error code: EXPORT_EXECUTION_NOT_FOUND    This API requires **SETTINGS_CONFIGURATION_GET_LAST_EXPORT_EXECUTION** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_last_export_execution_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ExportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_last_export_execution_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ExportExecutionResponse]:
        """Get the last export execution

        Get the last export execution    In case there was never been an export execution, an 404 error will be returned with error code: EXPORT_EXECUTION_NOT_FOUND    This API requires **SETTINGS_CONFIGURATION_GET_LAST_EXPORT_EXECUTION** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_last_export_execution_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ExportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_last_export_execution_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get the last export execution

        Get the last export execution    In case there was never been an export execution, an 404 error will be returned with error code: EXPORT_EXECUTION_NOT_FOUND    This API requires **SETTINGS_CONFIGURATION_GET_LAST_EXPORT_EXECUTION** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_last_export_execution_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ExportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_last_export_execution_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/configuration/exports/executions/last',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_last_import_execution(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ImportExecutionResponse:
        """Get the last import execution

        Get the last import execution    In case there was never been an import execution, an 404 error will be returned with error code: IMPORT_EXECUTION_NOT_FOUND    This API requires **SETTINGS_CONFIGURATION_GET_LAST_IMPORT_EXECUTION** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_last_import_execution_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ImportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_last_import_execution_with_http_info(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ImportExecutionResponse]:
        """Get the last import execution

        Get the last import execution    In case there was never been an import execution, an 404 error will be returned with error code: IMPORT_EXECUTION_NOT_FOUND    This API requires **SETTINGS_CONFIGURATION_GET_LAST_IMPORT_EXECUTION** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_last_import_execution_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ImportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_last_import_execution_without_preload_content(
        self,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get the last import execution

        Get the last import execution    In case there was never been an import execution, an 404 error will be returned with error code: IMPORT_EXECUTION_NOT_FOUND    This API requires **SETTINGS_CONFIGURATION_GET_LAST_IMPORT_EXECUTION** permission(s).  

        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_last_import_execution_serialize(
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '200': "ImportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '504': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_last_import_execution_serialize(
        self,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )


        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/v1/configuration/imports/executions/last',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def start_export(
        self,
        start_export_configuration_request: StartExportConfigurationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ExportExecutionResponse:
        """Start export configuration

        Start export configuration    Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |name|string|true||| |description|string|false|||   This API requires **SETTINGS_CONFIGURATION_START_EXPORT** permission(s).  

        :param start_export_configuration_request: (required)
        :type start_export_configuration_request: StartExportConfigurationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._start_export_serialize(
            start_export_configuration_request=start_export_configuration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "ExportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def start_export_with_http_info(
        self,
        start_export_configuration_request: StartExportConfigurationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ExportExecutionResponse]:
        """Start export configuration

        Start export configuration    Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |name|string|true||| |description|string|false|||   This API requires **SETTINGS_CONFIGURATION_START_EXPORT** permission(s).  

        :param start_export_configuration_request: (required)
        :type start_export_configuration_request: StartExportConfigurationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._start_export_serialize(
            start_export_configuration_request=start_export_configuration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "ExportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def start_export_without_preload_content(
        self,
        start_export_configuration_request: StartExportConfigurationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Start export configuration

        Start export configuration    Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |name|string|true||| |description|string|false|||   This API requires **SETTINGS_CONFIGURATION_START_EXPORT** permission(s).  

        :param start_export_configuration_request: (required)
        :type start_export_configuration_request: StartExportConfigurationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._start_export_serialize(
            start_export_configuration_request=start_export_configuration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "ExportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _start_export_serialize(
        self,
        start_export_configuration_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if start_export_configuration_request is not None:
            _body_params = start_export_configuration_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/configuration/exports/start',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def start_import(
        self,
        start_import_configuration_request: StartImportConfigurationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ImportExecutionResponse:
        """Start import configuration

        Start import configuration    Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |exportId|string|true||| |importType|string|true| Values:CLEAN_IMPORT||   This API requires **SETTINGS_CONFIGURATION_START_IMPORT** permission(s).  

        :param start_import_configuration_request: (required)
        :type start_import_configuration_request: StartImportConfigurationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._start_import_serialize(
            start_import_configuration_request=start_import_configuration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "ImportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def start_import_with_http_info(
        self,
        start_import_configuration_request: StartImportConfigurationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[ImportExecutionResponse]:
        """Start import configuration

        Start import configuration    Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |exportId|string|true||| |importType|string|true| Values:CLEAN_IMPORT||   This API requires **SETTINGS_CONFIGURATION_START_IMPORT** permission(s).  

        :param start_import_configuration_request: (required)
        :type start_import_configuration_request: StartImportConfigurationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._start_import_serialize(
            start_import_configuration_request=start_import_configuration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "ImportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def start_import_without_preload_content(
        self,
        start_import_configuration_request: StartImportConfigurationRequest,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Start import configuration

        Start import configuration    Request Body Parameters:  | Parameter   |Type   | Mandatory| Description          | Example   | |-------------|-------|----------|----------------------|-----------| |exportId|string|true||| |importType|string|true| Values:CLEAN_IMPORT||   This API requires **SETTINGS_CONFIGURATION_START_IMPORT** permission(s).  

        :param start_import_configuration_request: (required)
        :type start_import_configuration_request: StartImportConfigurationRequest
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._start_import_serialize(
            start_import_configuration_request=start_import_configuration_request,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '400': "ErrorResponse",
            '201': "ImportExecutionResponse",
            '500': "ErrorResponse",
            '401': "ErrorResponse",
            '403': "ErrorResponse",
            '404': "ErrorResponse",
            '504': "ErrorResponse",
            '409': "ErrorResponse",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _start_import_serialize(
        self,
        start_import_configuration_request,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[
            str, Union[str, bytes, List[str], List[bytes], List[Tuple[str, bytes]]]
        ] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        # process the header parameters
        # process the form parameters
        # process the body parameter
        if start_import_configuration_request is not None:
            _body_params = start_import_configuration_request


        # set the HTTP header `Accept`
        if 'Accept' not in _header_params:
            _header_params['Accept'] = self.api_client.select_header_accept(
                [
                    'application/json'
                ]
            )

        # set the HTTP header `Content-Type`
        if _content_type:
            _header_params['Content-Type'] = _content_type
        else:
            _default_content_type = (
                self.api_client.select_header_content_type(
                    [
                        'application/json'
                    ]
                )
            )
            if _default_content_type is not None:
                _header_params['Content-Type'] = _default_content_type

        # authentication setting
        _auth_settings: List[str] = [
            'bearerAuth'
        ]

        return self.api_client.param_serialize(
            method='POST',
            resource_path='/v1/configuration/imports/start',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.template_minimized_response import TemplateMinimizedResponse

class TestTemplateMinimizedResponse(unittest.TestCase):
    """TemplateMinimizedResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> TemplateMinimizedResponse:
        """Test TemplateMinimizedResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `TemplateMinimizedResponse`
        """
        model = TemplateMinimizedResponse()
        if include_optional:
            return TemplateMinimizedResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                description = '0',
                owner_organization_id = '',
                analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                    name = '', ),
                id = '',
                entity_type_name = '',
                removable = True,
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
                parent_template = biotmed_settings_sdk.models.parent_template_response.ParentTemplateResponse(
                    id = '', 
                    display_name = '', 
                    name = '', ),
                parent_template_id = ''
            )
        else:
            return TemplateMinimizedResponse(
                display_name = '0',
                name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua0',
                creation_time = '2007-12-20T10:15:30Z',
                last_modified_time = '2007-12-20T10:15:30Z',
        )
        """

    def testTemplateMinimizedResponse(self):
        """Test TemplateMinimizedResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.plugin_response import PluginResponse

class TestPluginResponse(unittest.TestCase):
    """PluginResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PluginResponse:
        """Test PluginResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PluginResponse`
        """
        model = PluginResponse()
        if include_optional:
            return PluginResponse(
                name = 'My-Plugin_3',
                display_name = 'My Plugin 3',
                version = 1,
                runtime = 'python3.13',
                handler = 'index.handler',
                timeout = 60,
                memory_size = 60,
                environment_variables = {
                    'key' : ''
                    },
                subscriptions = biotmed_settings_sdk.models.subscription_dto.SubscriptionDto(
                    interception_order = 56, 
                    interceptions = [
                        biotmed_settings_sdk.models.interception_subscription_dto.InterceptionSubscriptionDto(
                            type = 'PRE_REQUEST', 
                            api_id = '', 
                            entity_type_name = 'device', 
                            order = 56, )
                        ], 
                    notifications = [
                        biotmed_settings_sdk.models.notification_subscription_dto.NotificationSubscriptionDto(
                            entity_type_name = 'device', 
                            action_name = '_create', )
                        ], ),
                enabled_state = 'ENABLED',
                cron_schedule = '45',
                deployment_package_type = 'ZIP',
                analytics_db_access = True,
                cors = biotmed_settings_sdk.models.plugin_cors_config.PluginCorsConfig(
                    allow_origins = [*], 
                    allow_methods = [GET, POST], 
                    allow_headers = [authorization, content-type], 
                    expose_headers = [], ),
                ephemeral_storage = 512,
                endpoint_url = '',
                link_to_console = '',
                last_modified_time = '2007-12-20T10:15:30Z',
                creation_time = '2007-12-20T10:15:30Z'
            )
        else:
            return PluginResponse(
                name = 'My-Plugin_3',
                display_name = 'My Plugin 3',
                version = 1,
                timeout = 60,
                memory_size = 60,
                environment_variables = {
                    'key' : ''
                    },
                enabled_state = 'ENABLED',
                deployment_package_type = 'ZIP',
                analytics_db_access = True,
                endpoint_url = '',
                link_to_console = '',
                last_modified_time = '2007-12-20T10:15:30Z',
                creation_time = '2007-12-20T10:15:30Z',
        )
        """

    def testPluginResponse(self):
        """Test PluginResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field
from typing import Any, ClassVar, Dict, List, Optional
from biotmed_settings_sdk.models.json_nullable_list_cors_allowed_http_method_enum import JsonNullableListCorsAllowedHttpMethodEnum
from biotmed_settings_sdk.models.json_nullable_list_string import JsonNullableListString

from typing import Optional, Set
from typing_extensions import Self

# BioT Code Start: extra/custom attributes support imports
from typing import Any, Dict, ClassVar, List
from pydantic import Field, model_validator
# BioT Code End

class PartialPluginCorsConfig(BaseModel):
    """
    Partial CORS configuration for plugin updates. Only provided fields will be updated. These settings affect which browser origins are allowed to call the plugin and what request/response properties are permitted. They impact browser-enforced access (CORS), not server-to-server calls.

    Note: This model supports custom attributes. Recommended access:
      - Pass custom fields via dict unpacking: Model(..., **{"custom_field": "value"})
      - Read custom fields via model.get("custom_field") or model["custom_field"]
    """ # noqa: E501
    allow_origins: Optional[JsonNullableListString] = Field(default=None, description="List of allowed origins. Controls which browser origins can access the plugin. '*' allows any origin (useful for development; best to avoid in production). Specify explicit origins like 'https://app.example.com' (optionally with port) to restrict access. If an origin is not listed, the browser will block requests from that page even if the server responds. Omit this field to keep the current origins. Sending [] removes all origins. Providing a list replaces the existing value.", alias="allowOrigins")
    allow_methods: Optional[JsonNullableListCorsAllowedHttpMethodEnum] = Field(default=None, description="List of allowed HTTP methods for CORS. Only GET, PUT, POST, DELETE, HEAD, and PATCH are supported. Methods not included may be blocked by the browser during preflight or actual requests (even if the backend supports them). Omit this field to keep the current allowed methods. Sending [] removes all methods. Providing a list replaces the existing value.", alias="allowMethods")
    allow_headers: Optional[JsonNullableListString] = Field(default=None, description="List of request headers the browser is allowed to send. Include any custom or non-simple headers (e.g. 'authorization', 'x-request-id'), otherwise the browser will fail the CORS preflight. Omit this field to keep the current allowed headers. Sending [] removes all headers. Providing a list replaces the existing value.", alias="allowHeaders")
    expose_headers: Optional[JsonNullableListString] = Field(default=None, description="List of response headers that should be readable by browser clients (via fetch/XHR). Without listing here, only CORS-safelisted headers are visible to client code. This does not gate access; it only controls header visibility. Omit this field to keep the current expose headers. Sending [] removes all headers. Providing a list replaces the existing value.", alias="exposeHeaders")
    # BioT Code Start: Store custom attributes in a dedicated dict (safe default)
    additional_properties: Dict[str, Any] = Field(default_factory=dict)
    # BioT Code End
    __properties: ClassVar[List[str]] = ["allowOrigins", "allowMethods", "allowHeaders", "exposeHeaders"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        # BioT Code Start: Allow extra fields for custom attributes
        extra='allow',
        # BioT Code End
    )

    # BioT Code Start: Sync Pydantic v2 extras into additional_properties
    @model_validator(mode='after')
    def _sync_additional_properties(self):
        """
        Sync unknown fields from Pydantic v2 `model_extra` into additional_properties.

        - When `extra='allow'`, unknown fields are stored in `model_extra`.
        - We copy them into additional_properties for OpenAPI Generator compatibility.
        """
        if self.model_extra:
            self.additional_properties.update(self.model_extra)
        return self
    # BioT Code End

    # BioT Code Start: Make dot-access to custom attributes type-check as Any (pyright-friendly)
    def __getattr__(self, item: str) -> Any:
        """
        Fallback for dynamic/custom attributes.

        This makes `model.some_custom_attr` resolve to `Any` in static type checkers
        instead of raising `reportUnknownMemberType`.
        """
        if item in self.additional_properties:
            return self.additional_properties[item]
        # also check model_extra directly (in case sync didn't run yet)
        if self.model_extra and item in self.model_extra:
            return self.model_extra[item]
        raise AttributeError(f"'{self.__class__.__name__}' has no field or custom property '{item}'")
    # BioT Code End

    # BioT Code Start: Dict-style access for custom attributes (and fields)
    def __getitem__(self, key: str) -> Any:
        """
        Support dict-style access:
          - defined fields by python name (e.g. 'name')
          - defined fields by alias (e.g. '_name') via to_dict fallback
          - custom attributes stored in additional_properties
        """
        if key in self.additional_properties:
            return self.additional_properties[key]
        if self.model_extra and key in self.model_extra:
            return self.model_extra[key]

        # Try direct attribute (python field name)
        if hasattr(self, key):
            try:
                return getattr(self, key)
            except AttributeError:
                pass

        # Try alias / serialized keys through to_dict()
        d = self.to_dict()
        if key in d:
            return d[key]

        raise KeyError(f"'{self.__class__.__name__}' has no field or custom property '{key}'")

    def get(self, key: str, default: Any = None) -> Any:
        """dict.get() style safe access."""
        try:
            return self[key]
        except KeyError:
            return default
    # BioT Code End

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    # BioT Code Start: Override model_dump_json to flatten custom attributes to top level
    def model_dump_json(self, *, indent: Optional[int] = None, by_alias: bool = True, **kwargs: Any) -> str:
        """Return JSON representation with custom attributes flattened to top level."""
        json_kwargs = {k: v for k, v in kwargs.items()
                      if k not in ['by_alias', 'exclude', 'exclude_none', 'exclude_unset',
                                   'exclude_defaults', 'include', 'mode', 'round_trip',
                                   'warnings', 'serialize_as_any']}
        return json.dumps(self.to_dict(), indent=indent, default=str, **json_kwargs)
    # BioT Code End

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of PartialPluginCorsConfig from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of allow_origins
        if self.allow_origins:
            _dict['allowOrigins'] = self.allow_origins.to_dict()
        # override the default output from pydantic by calling `to_dict()` of allow_methods
        if self.allow_methods:
            _dict['allowMethods'] = self.allow_methods.to_dict()
        # override the default output from pydantic by calling `to_dict()` of allow_headers
        if self.allow_headers:
            _dict['allowHeaders'] = self.allow_headers.to_dict()
        # override the default output from pydantic by calling `to_dict()` of expose_headers
        if self.expose_headers:
            _dict['exposeHeaders'] = self.expose_headers.to_dict()
        # BioT Code Start: puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value
        # BioT Code End
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of PartialPluginCorsConfig from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "allowOrigins": JsonNullableListString.from_dict(obj["allowOrigins"]) if obj.get("allowOrigins") is not None else None,
            "allowMethods": JsonNullableListCorsAllowedHttpMethodEnum.from_dict(obj["allowMethods"]) if obj.get("allowMethods") is not None else None,
            "allowHeaders": JsonNullableListString.from_dict(obj["allowHeaders"]) if obj.get("allowHeaders") is not None else None,
            "exposeHeaders": JsonNullableListString.from_dict(obj["exposeHeaders"]) if obj.get("exposeHeaders") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.filter_v2 import FilterV2

class TestFilterV2(unittest.TestCase):
    """FilterV2 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> FilterV2:
        """Test FilterV2
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `FilterV2`
        """
        model = FilterV2()
        if include_optional:
            return FilterV2(
                var_in = [
                    ''
                    ],
                eq = None,
                lt = 20,
                lte = 25,
                gt = 25,
                gte = 25,
                like = 'John',
                var_from = '2007-12-20',
                to = '2007-12-20',
                is_null = True,
                is_not_null = True,
                var_not = None,
                not_in = [
                    ''
                    ],
                filter = None
            )
        else:
            return FilterV2(
        )
        """

    def testFilterV2(self):
        """Test FilterV2"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.locale_api_api import LocaleAPIApi


class TestLocaleAPIApi(unittest.TestCase):
    """LocaleAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LocaleAPIApi()

    def tearDown(self) -> None:
        pass

    def test_add_locale(self) -> None:
        """Test case for add_locale

        Add locale to the available locales
        """
        pass

    def test_delete_locale(self) -> None:
        """Test case for delete_locale

        Remove a locale from the available locales
        """
        pass

    def test_get_locales(self) -> None:
        """Test case for get_locales

        Get available locales, the default locale and the system locale
        """
        pass

    def test_update_locales(self) -> None:
        """Test case for update_locales

        Update available locales and/or the system default locale.
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.interception_configuration_api_api import InterceptionConfigurationAPIApi


class TestInterceptionConfigurationAPIApi(unittest.TestCase):
    """InterceptionConfigurationAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = InterceptionConfigurationAPIApi()

    def tearDown(self) -> None:
        pass

    def test_search3(self) -> None:
        """Test case for search3

        Search Interception Configurations entities by filter
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.entity_type_built_in_attribute import EntityTypeBuiltInAttribute

class TestEntityTypeBuiltInAttribute(unittest.TestCase):
    """EntityTypeBuiltInAttribute unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> EntityTypeBuiltInAttribute:
        """Test EntityTypeBuiltInAttribute
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `EntityTypeBuiltInAttribute`
        """
        model = EntityTypeBuiltInAttribute()
        if include_optional:
            return EntityTypeBuiltInAttribute(
                name = '',
                base_path = '',
                type = 'LABEL',
                display_name = '',
                phi = True,
                validation = biotmed_settings_sdk.models.validation_definition_object.ValidationDefinitionObject(
                    mandatory = True, 
                    default_value = null, 
                    min = -9223372036854775808, 
                    max = -9223372036854775808, 
                    regex = '', ),
                validation_metadata = biotmed_settings_sdk.models.validation_definition_metadata_object.ValidationDefinitionMetadataObject(
                    mandatory_read_only = True, 
                    system_mandatory = True, 
                    phi_read_only = True, ),
                selectable_values = [
                    biotmed_settings_sdk.models.base_selectable_value.BaseSelectableValue(
                        name = 'AqXzyCBw3_uufVPIPFhB9JcGRYnua', 
                        display_name = '', )
                    ],
                read_only = True,
                reference_configuration = biotmed_settings_sdk.models.reference_configuration.ReferenceConfiguration(
                    uniquely = True, 
                    referenced_side_attribute_name = '', 
                    referenced_side_attribute_display_name = '', 
                    valid_templates_to_reference = [
                        ''
                        ], 
                    entity_type = '', ),
                numeric_meta_data = biotmed_settings_sdk.models.numeric_meta_data.NumericMetaData(
                    units = '', 
                    upper_range = -2147483648, 
                    lower_range = -2147483648, 
                    sub_type = 'INTEGER', ),
                category = biotmed_settings_sdk.models.category.Category(
                    name = '', 
                    display_name = '', ),
                analytics_db_configuration = biotmed_settings_sdk.models.attribute_analytics_db_configuration.AttributeAnalyticsDbConfiguration(
                    name = '', ),
                type_enum = 'LABEL'
            )
        else:
            return EntityTypeBuiltInAttribute(
                name = '',
        )
        """

    def testEntityTypeBuiltInAttribute(self):
        """Test EntityTypeBuiltInAttribute"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.template_api_api import TemplateAPIApi


class TestTemplateAPIApi(unittest.TestCase):
    """TemplateAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TemplateAPIApi()

    def tearDown(self) -> None:
        pass

    def test_create_template(self) -> None:
        """Test case for create_template

        Create a new Template
        """
        pass

    def test_delete_template(self) -> None:
        """Test case for delete_template

        Delete Template
        """
        pass

    def test_get_template(self) -> None:
        """Test case for get_template

        Get Template by ID
        """
        pass

    def test_get_template_overview(self) -> None:
        """Test case for get_template_overview

        Get template overview
        """
        pass

    def test_minimal_search(self) -> None:
        """Test case for minimal_search

        Search Template entities by filter
        """
        pass

    def test_search1(self) -> None:
        """Test case for search1

        Search Template entities by filter
        """
        pass

    def test_update_template(self) -> None:
        """Test case for update_template

        Update Template
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.translation_api_api import TranslationAPIApi


class TestTranslationAPIApi(unittest.TestCase):
    """TranslationAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = TranslationAPIApi()

    def tearDown(self) -> None:
        pass

    def test_delete_locale_translations(self) -> None:
        """Test case for delete_locale_translations

        Delete all translations for locale
        """
        pass

    def test_download_locale_translation_file(self) -> None:
        """Test case for download_locale_translation_file

        Download locale translation file
        """
        pass

    def test_search_locale_translation_overviews(self) -> None:
        """Test case for search_locale_translation_overviews

        Search Locale translations overview entities by filter
        """
        pass

    def test_update_locale_translations(self) -> None:
        """Test case for update_locale_translations

        Update translations for locale
        """
        pass

    def test_validate_locale_translations(self) -> None:
        """Test case for validate_locale_translations

        Validate translations for locale
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.api.export_import_configuration_api_api import ExportImportConfigurationAPIApi


class TestExportImportConfigurationAPIApi(unittest.TestCase):
    """ExportImportConfigurationAPIApi unit test stubs"""

    def setUp(self) -> None:
        self.api = ExportImportConfigurationAPIApi()

    def tearDown(self) -> None:
        pass

    def test_get_exports_metadata(self) -> None:
        """Test case for get_exports_metadata

        Get exported files metadata
        """
        pass

    def test_get_last_export_execution(self) -> None:
        """Test case for get_last_export_execution

        Get the last export execution
        """
        pass

    def test_get_last_import_execution(self) -> None:
        """Test case for get_last_import_execution

        Get the last import execution
        """
        pass

    def test_start_export(self) -> None:
        """Test case for start_export

        Start export configuration
        """
        pass

    def test_start_import(self) -> None:
        """Test case for start_import

        Start import configuration
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from biotmed_settings_sdk.models.docker_repository_temp_credentials_response import DockerRepositoryTempCredentialsResponse

class TestDockerRepositoryTempCredentialsResponse(unittest.TestCase):
    """DockerRepositoryTempCredentialsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DockerRepositoryTempCredentialsResponse:
        """Test DockerRepositoryTempCredentialsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DockerRepositoryTempCredentialsResponse`
        """
        model = DockerRepositoryTempCredentialsResponse()
        if include_optional:
            return DockerRepositoryTempCredentialsResponse(
                credentials = biotmed_settings_sdk.models.credentials.Credentials(
                    access_key_id = '', 
                    secret_access_key = '', 
                    session_token = '', 
                    expiration = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ),
                region = '',
                repository_uri = ''
            )
        else:
            return DockerRepositoryTempCredentialsResponse(
        )
        """

    def testDockerRepositoryTempCredentialsResponse(self):
        """Test DockerRepositoryTempCredentialsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    BioT Settings Service

    APIs document description for Settings service

    The version of the OpenAPI document: 2.44.1
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from biotmed_settings_sdk.models.filter_v2 import FilterV2
from biotmed_settings_sdk.models.order import Order

from typing import Optional, Set
from typing_extensions import Self

# BioT Code Start: extra/custom attributes support imports
from typing import Any, Dict, ClassVar, List
from pydantic import Field, model_validator
# BioT Code End

class SearchRequestV2(BaseModel):
    """
    SearchRequestV2

    Note: This model supports custom attributes. Recommended access:
      - Pass custom fields via dict unpacking: Model(..., **{"custom_field": "value"})
      - Read custom fields via model.get("custom_field") or model["custom_field"]
    """ # noqa: E501
    filter: Optional[Dict[str, FilterV2]] = Field(default=None, description="Each additionalProp can filter one field, inside additionalProp there are many optional conditions that can be used for filtering that field. When multiple conditions are specified, they are bundled together using logical AND operators, this means that only the items that match all filter conditions for that field will be returned")
    sort: Optional[List[Order]] = Field(default=None, description="Results can be sorted by multiple fields, the order of the fields in the sort request governs the hierarchy of the sort.The first field is the primary sort, the second is used when two values of the first field are the same, and so forth")
    free_text_search: Optional[StrictStr] = Field(default=None, description="Free text search strings - will be bundled to the filters with the logical AND operator. Possible to pass a few strings with space between them, the search will return a result if one of strings appears in the data entity (OR operator).", alias="freeTextSearch")
    limit: Optional[Annotated[int, Field(strict=True, ge=1)]] = None
    page: Optional[Annotated[int, Field(strict=True, ge=0)]] = None
    # BioT Code Start: Store custom attributes in a dedicated dict (safe default)
    additional_properties: Dict[str, Any] = Field(default_factory=dict)
    # BioT Code End
    __properties: ClassVar[List[str]] = ["filter", "sort", "freeTextSearch", "limit", "page"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
        # BioT Code Start: Allow extra fields for custom attributes
        extra='allow',
        # BioT Code End
    )

    # BioT Code Start: Sync Pydantic v2 extras into additional_properties
    @model_validator(mode='after')
    def _sync_additional_properties(self):
        """
        Sync unknown fields from Pydantic v2 `model_extra` into additional_properties.

        - When `extra='allow'`, unknown fields are stored in `model_extra`.
        - We copy them into additional_properties for OpenAPI Generator compatibility.
        """
        if self.model_extra:
            self.additional_properties.update(self.model_extra)
        return self
    # BioT Code End

    # BioT Code Start: Make dot-access to custom attributes type-check as Any (pyright-friendly)
    def __getattr__(self, item: str) -> Any:
        """
        Fallback for dynamic/custom attributes.

        This makes `model.some_custom_attr` resolve to `Any` in static type checkers
        instead of raising `reportUnknownMemberType`.
        """
        if item in self.additional_properties:
            return self.additional_properties[item]
        # also check model_extra directly (in case sync didn't run yet)
        if self.model_extra and item in self.model_extra:
            return self.model_extra[item]
        raise AttributeError(f"'{self.__class__.__name__}' has no field or custom property '{item}'")
    # BioT Code End

    # BioT Code Start: Dict-style access for custom attributes (and fields)
    def __getitem__(self, key: str) -> Any:
        """
        Support dict-style access:
          - defined fields by python name (e.g. 'name')
          - defined fields by alias (e.g. '_name') via to_dict fallback
          - custom attributes stored in additional_properties
        """
        if key in self.additional_properties:
            return self.additional_properties[key]
        if self.model_extra and key in self.model_extra:
            return self.model_extra[key]

        # Try direct attribute (python field name)
        if hasattr(self, key):
            try:
                return getattr(self, key)
            except AttributeError:
                pass

        # Try alias / serialized keys through to_dict()
        d = self.to_dict()
        if key in d:
            return d[key]

        raise KeyError(f"'{self.__class__.__name__}' has no field or custom property '{key}'")

    def get(self, key: str, default: Any = None) -> Any:
        """dict.get() style safe access."""
        try:
            return self[key]
        except KeyError:
            return default
    # BioT Code End

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    # BioT Code Start: Override model_dump_json to flatten custom attributes to top level
    def model_dump_json(self, *, indent: Optional[int] = None, by_alias: bool = True, **kwargs: Any) -> str:
        """Return JSON representation with custom attributes flattened to top level."""
        json_kwargs = {k: v for k, v in kwargs.items()
                      if k not in ['by_alias', 'exclude', 'exclude_none', 'exclude_unset',
                                   'exclude_defaults', 'include', 'mode', 'round_trip',
                                   'warnings', 'serialize_as_any']}
        return json.dumps(self.to_dict(), indent=indent, default=str, **json_kwargs)
    # BioT Code End

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SearchRequestV2 from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each value in filter (dict)
        _field_dict = {}
        if self.filter:
            for _key_filter in self.filter:
                if self.filter[_key_filter]:
                    _field_dict[_key_filter] = self.filter[_key_filter].to_dict()
            _dict['filter'] = _field_dict
        # override the default output from pydantic by calling `to_dict()` of each item in sort (list)
        _items = []
        if self.sort:
            for _item_sort in self.sort:
                if _item_sort:
                    _items.append(_item_sort.to_dict())
            _dict['sort'] = _items
        # BioT Code Start: puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value
        # BioT Code End
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SearchRequestV2 from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "filter": dict(
                (_k, FilterV2.from_dict(_v))
                for _k, _v in obj["filter"].items()
            )
            if obj.get("filter") is not None
            else None,
            "sort": [Order.from_dict(_item) for _item in obj["sort"]] if obj.get("sort") is not None else None,
            "freeTextSearch": obj.get("freeTextSearch"),
            "limit": obj.get("limit"),
            "page": obj.get("page")
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj


